@@ -1,7 +1,7 @@
 package RDF::DOAP::Project;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.101';
+our $VERSION   = '0.102';
 
 use Moose;
 extends qw(RDF::DOAP::Resource);
@@ -138,7 +138,7 @@ sub changelog
 		if (@releases) {
 			my $found_catchup = undef;
 			for my $i (0 .. $#releases) {
-				for my $cs (@{ $releases[$i]->changesets }) {
+				for my $cs (@{ $releases[$i]->changesets || [] }) {
 					if ($cs->has_versus and $cs->versus->revision eq $next->revision) {
 						$found_catchup = $i;
 					}
